# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: project_aoi.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from terrascope_api.models import aoi_pb2 as aoi__pb2
try:
  common__models__pb2 = aoi__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = aoi__pb2.common_models_pb2
from terrascope_api.models import common_models_pb2 as common__models__pb2

from terrascope_api.models.aoi_pb2 import *
from terrascope_api.models.common_models_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11project_aoi.proto\x12\x07oi.papi\x1a\taoi.proto\x1a\x13\x63ommon_models.proto\"e\n\x17ProjectAOICreateRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x0f\n\x07\x61oi_ids\x18\x02 \x03(\t\x12%\n\naoi_inputs\x18\x03 \x03(\x0b\x32\x11.oi.papi.AOIInput\"X\n\x18ProjectAOICreateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\'\n\x0b\x61oi_objects\x18\x02 \x03(\x0b\x32\x12.oi.papi.AOIObject\"<\n\x17ProjectAOIUploadRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\r\n\x05\x63hunk\x18\x02 \x01(\x0c\"e\n\x1cProjectAOIFileUploadResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x30\n\x0f\x61oi_transaction\x18\x02 \x01(\x0b\x32\x17.oi.papi.AOITransaction\">\n\x17ProjectAOIDeleteRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x0f\n\x07\x61oi_ids\x18\x02 \x03(\t\"/\n\x18ProjectAOIDeleteResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\"S\n\x14ProjectAOIGetRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\'\n\npagination\x18\x02 \x01(\x0b\x32\x13.oi.papi.Pagination\"u\n\x11\x41OICollectionAOIs\x12\x19\n\x11\x61oi_collection_id\x18\x01 \x01(\t\x12\x1c\n\x14\x61oi_collection_state\x18\x02 \x01(\t\x12\'\n\x0b\x61oi_objects\x18\x03 \x03(\x0b\x32\x12.oi.papi.AOIObject\"\x8e\x01\n\x15ProjectAOIGetResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x37\n\x13\x61oi_collection_aois\x18\x02 \x03(\x0b\x32\x1a.oi.papi.AOICollectionAOIs\x12\'\n\npagination\x18\x03 \x01(\x0b\x32\x13.oi.papi.Pagination\"p\n\x17ProjectAOIUpdateRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x0e\n\x06\x61oi_id\x18\x02 \x01(\t\x12\x31\n\x16\x61oi_modification_input\x18\x03 \x01(\x0b\x32\x11.oi.papi.AOIInput\"h\n\x18ProjectAOIUpdateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x37\n\x13\x61oi_collection_aois\x18\x02 \x01(\x0b\x32\x1a.oi.papi.AOICollectionAOIs2\x97\x03\n\rProjectAOIApi\x12M\n\x06\x63reate\x12 .oi.papi.ProjectAOICreateRequest\x1a!.oi.papi.ProjectAOICreateResponse\x12S\n\x06upload\x12 .oi.papi.ProjectAOIUploadRequest\x1a%.oi.papi.ProjectAOIFileUploadResponse(\x01\x12M\n\x06\x64\x65lete\x12 .oi.papi.ProjectAOIDeleteRequest\x1a!.oi.papi.ProjectAOIDeleteResponse\x12\x44\n\x03get\x12\x1d.oi.papi.ProjectAOIGetRequest\x1a\x1e.oi.papi.ProjectAOIGetResponse\x12M\n\x06update\x12 .oi.papi.ProjectAOIUpdateRequest\x1a!.oi.papi.ProjectAOIUpdateResponseP\x00P\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'project_aoi_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_PROJECTAOICREATEREQUEST']._serialized_start=62
  _globals['_PROJECTAOICREATEREQUEST']._serialized_end=163
  _globals['_PROJECTAOICREATERESPONSE']._serialized_start=165
  _globals['_PROJECTAOICREATERESPONSE']._serialized_end=253
  _globals['_PROJECTAOIUPLOADREQUEST']._serialized_start=255
  _globals['_PROJECTAOIUPLOADREQUEST']._serialized_end=315
  _globals['_PROJECTAOIFILEUPLOADRESPONSE']._serialized_start=317
  _globals['_PROJECTAOIFILEUPLOADRESPONSE']._serialized_end=418
  _globals['_PROJECTAOIDELETEREQUEST']._serialized_start=420
  _globals['_PROJECTAOIDELETEREQUEST']._serialized_end=482
  _globals['_PROJECTAOIDELETERESPONSE']._serialized_start=484
  _globals['_PROJECTAOIDELETERESPONSE']._serialized_end=531
  _globals['_PROJECTAOIGETREQUEST']._serialized_start=533
  _globals['_PROJECTAOIGETREQUEST']._serialized_end=616
  _globals['_AOICOLLECTIONAOIS']._serialized_start=618
  _globals['_AOICOLLECTIONAOIS']._serialized_end=735
  _globals['_PROJECTAOIGETRESPONSE']._serialized_start=738
  _globals['_PROJECTAOIGETRESPONSE']._serialized_end=880
  _globals['_PROJECTAOIUPDATEREQUEST']._serialized_start=882
  _globals['_PROJECTAOIUPDATEREQUEST']._serialized_end=994
  _globals['_PROJECTAOIUPDATERESPONSE']._serialized_start=996
  _globals['_PROJECTAOIUPDATERESPONSE']._serialized_end=1100
  _globals['_PROJECTAOIAPI']._serialized_start=1103
  _globals['_PROJECTAOIAPI']._serialized_end=1510
# @@protoc_insertion_point(module_scope)
