# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from terrascope_api.models import project_result_pb2 as project__result__pb2

GRPC_GENERATED_VERSION = '1.65.4'
GRPC_VERSION = grpc.__version__
EXPECTED_ERROR_RELEASE = '1.66.0'
SCHEDULED_RELEASE_DATE = 'August 6, 2024'
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    warnings.warn(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in project_result_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
        + f' This warning will become an error in {EXPECTED_ERROR_RELEASE},'
        + f' scheduled for release on {SCHEDULED_RELEASE_DATE}.',
        RuntimeWarning
    )


class ProjectResultApiStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.create_filter_mapping = channel.unary_unary(
                '/oi.papi.ProjectResultApi/create_filter_mapping',
                request_serializer=project__result__pb2.ProjectResultFilterMappingCreateRequest.SerializeToString,
                response_deserializer=project__result__pb2.ProjectResultFilterMappingCreateResponse.FromString,
                _registered_method=True)
        self.delete_filter_mapping = channel.unary_unary(
                '/oi.papi.ProjectResultApi/delete_filter_mapping',
                request_serializer=project__result__pb2.ProjectResultFilterMappingDeleteRequest.SerializeToString,
                response_deserializer=project__result__pb2.ProjectResultFilterMappingDeleteResponse.FromString,
                _registered_method=True)
        self.get = channel.unary_unary(
                '/oi.papi.ProjectResultApi/get',
                request_serializer=project__result__pb2.ProjectResultGetRequest.SerializeToString,
                response_deserializer=project__result__pb2.ProjectResultGetResponse.FromString,
                _registered_method=True)
        self.get_status = channel.unary_unary(
                '/oi.papi.ProjectResultApi/get_status',
                request_serializer=project__result__pb2.ProjectResultGetStatusRequest.SerializeToString,
                response_deserializer=project__result__pb2.ProjectResultGetStatusResponse.FromString,
                _registered_method=True)
        self.get_download = channel.unary_unary(
                '/oi.papi.ProjectResultApi/get_download',
                request_serializer=project__result__pb2.ProjectResultGetDownloadRequest.SerializeToString,
                response_deserializer=project__result__pb2.ProjectResultGetDownloadResponse.FromString,
                _registered_method=True)
        self.generate_download = channel.unary_unary(
                '/oi.papi.ProjectResultApi/generate_download',
                request_serializer=project__result__pb2.ProjectResultGenerateDownloadRequest.SerializeToString,
                response_deserializer=project__result__pb2.ProjectResultGenerateDownloadResponse.FromString,
                _registered_method=True)


class ProjectResultApiServicer(object):
    """Missing associated documentation comment in .proto file."""

    def create_filter_mapping(self, request, context):
        """
        Create a project result filter mapping
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def delete_filter_mapping(self, request, context):
        """
        Delete a project result filter mapping
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get(self, request, context):
        """
        Get Project Results
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get_status(self, request, context):
        """
        Get Project Result Status
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get_download(self, request, context):
        """
        Get Project Result Download
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def generate_download(self, request, context):
        """
        Generate Project Result Download
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ProjectResultApiServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'create_filter_mapping': grpc.unary_unary_rpc_method_handler(
                    servicer.create_filter_mapping,
                    request_deserializer=project__result__pb2.ProjectResultFilterMappingCreateRequest.FromString,
                    response_serializer=project__result__pb2.ProjectResultFilterMappingCreateResponse.SerializeToString,
            ),
            'delete_filter_mapping': grpc.unary_unary_rpc_method_handler(
                    servicer.delete_filter_mapping,
                    request_deserializer=project__result__pb2.ProjectResultFilterMappingDeleteRequest.FromString,
                    response_serializer=project__result__pb2.ProjectResultFilterMappingDeleteResponse.SerializeToString,
            ),
            'get': grpc.unary_unary_rpc_method_handler(
                    servicer.get,
                    request_deserializer=project__result__pb2.ProjectResultGetRequest.FromString,
                    response_serializer=project__result__pb2.ProjectResultGetResponse.SerializeToString,
            ),
            'get_status': grpc.unary_unary_rpc_method_handler(
                    servicer.get_status,
                    request_deserializer=project__result__pb2.ProjectResultGetStatusRequest.FromString,
                    response_serializer=project__result__pb2.ProjectResultGetStatusResponse.SerializeToString,
            ),
            'get_download': grpc.unary_unary_rpc_method_handler(
                    servicer.get_download,
                    request_deserializer=project__result__pb2.ProjectResultGetDownloadRequest.FromString,
                    response_serializer=project__result__pb2.ProjectResultGetDownloadResponse.SerializeToString,
            ),
            'generate_download': grpc.unary_unary_rpc_method_handler(
                    servicer.generate_download,
                    request_deserializer=project__result__pb2.ProjectResultGenerateDownloadRequest.FromString,
                    response_serializer=project__result__pb2.ProjectResultGenerateDownloadResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'oi.papi.ProjectResultApi', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('oi.papi.ProjectResultApi', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class ProjectResultApi(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def create_filter_mapping(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.ProjectResultApi/create_filter_mapping',
            project__result__pb2.ProjectResultFilterMappingCreateRequest.SerializeToString,
            project__result__pb2.ProjectResultFilterMappingCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def delete_filter_mapping(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.ProjectResultApi/delete_filter_mapping',
            project__result__pb2.ProjectResultFilterMappingDeleteRequest.SerializeToString,
            project__result__pb2.ProjectResultFilterMappingDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.ProjectResultApi/get',
            project__result__pb2.ProjectResultGetRequest.SerializeToString,
            project__result__pb2.ProjectResultGetResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def get_status(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.ProjectResultApi/get_status',
            project__result__pb2.ProjectResultGetStatusRequest.SerializeToString,
            project__result__pb2.ProjectResultGetStatusResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def get_download(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.ProjectResultApi/get_download',
            project__result__pb2.ProjectResultGetDownloadRequest.SerializeToString,
            project__result__pb2.ProjectResultGetDownloadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def generate_download(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/oi.papi.ProjectResultApi/generate_download',
            project__result__pb2.ProjectResultGenerateDownloadRequest.SerializeToString,
            project__result__pb2.ProjectResultGenerateDownloadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)
