# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tile.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from terrascope_api.models import common_models_pb2 as common__models__pb2

from terrascope_api.models.common_models_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\ntile.proto\x12\x0coi.papi.tile\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x13\x63ommon_models.proto\"D\n\x06\x42ounds\x12\r\n\x05x_min\x18\x01 \x01(\x02\x12\r\n\x05y_min\x18\x02 \x01(\x02\x12\r\n\x05x_max\x18\x03 \x01(\x02\x12\r\n\x05y_max\x18\x04 \x01(\x02\"&\n\nTileMatrix\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04zoom\x18\x02 \x01(\x05\"T\n\x0eTileAccessInfo\x12\x14\n\x0curl_template\x18\x01 \x01(\t\x12,\n\x0b\x63redentials\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\"\xd5\x01\n\x07TileSet\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12$\n\x06\x62ounds\x18\x03 \x01(\x0b\x32\x14.oi.papi.tile.Bounds\x12*\n\x08matrices\x18\x04 \x03(\x0b\x32\x18.oi.papi.tile.TileMatrix\x12\x31\n\x0btile_access\x18\x05 \x01(\x0b\x32\x1c.oi.papi.tile.TileAccessInfo\x12+\n\x07\x66rom_ts\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xb2\x01\n\x12TileSetListRequest\x12\x11\n\tsearch_id\x18\x01 \x01(\t\x12\'\n\npagination\x18\x02 \x01(\x0b\x32\x13.oi.papi.Pagination\x12\x30\n\x0ctile_ts_from\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\ntile_ts_to\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"h\n\x13TileSetListResponse\x12(\n\ttile_sets\x18\x01 \x03(\x0b\x32\x15.oi.papi.tile.TileSet\x12\'\n\npagination\x18\x02 \x01(\x0b\x32\x13.oi.papi.Pagination2V\n\x07TileApi\x12K\n\x04list\x12 .oi.papi.tile.TileSetListRequest\x1a!.oi.papi.tile.TileSetListResponseP\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tile_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_BOUNDS']._serialized_start=112
  _globals['_BOUNDS']._serialized_end=180
  _globals['_TILEMATRIX']._serialized_start=182
  _globals['_TILEMATRIX']._serialized_end=220
  _globals['_TILEACCESSINFO']._serialized_start=222
  _globals['_TILEACCESSINFO']._serialized_end=306
  _globals['_TILESET']._serialized_start=309
  _globals['_TILESET']._serialized_end=522
  _globals['_TILESETLISTREQUEST']._serialized_start=525
  _globals['_TILESETLISTREQUEST']._serialized_end=703
  _globals['_TILESETLISTRESPONSE']._serialized_start=705
  _globals['_TILESETLISTRESPONSE']._serialized_end=809
  _globals['_TILEAPI']._serialized_start=811
  _globals['_TILEAPI']._serialized_end=897
# @@protoc_insertion_point(module_scope)
