# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: project_group.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from terrascope_api.models import common_models_pb2 as common__models__pb2
from terrascope_api.models import project_pb2 as project__pb2
try:
  common__models__pb2 = project__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = project__pb2.common_models_pb2
try:
  analysis__config__pb2 = project__pb2.analysis__config__pb2
except AttributeError:
  analysis__config__pb2 = project__pb2.analysis_config_pb2
try:
  common__models__pb2 = project__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = project__pb2.common_models_pb2
try:
  analysis__pb2 = project__pb2.analysis__pb2
except AttributeError:
  analysis__pb2 = project__pb2.analysis_pb2
try:
  common__models__pb2 = project__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = project__pb2.common_models_pb2
try:
  analysis__version__pb2 = project__pb2.analysis__version__pb2
except AttributeError:
  analysis__version__pb2 = project__pb2.analysis_version_pb2
try:
  common__models__pb2 = project__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = project__pb2.common_models_pb2
try:
  analysis__pb2 = project__pb2.analysis__pb2
except AttributeError:
  analysis__pb2 = project__pb2.analysis_pb2
try:
  common__models__pb2 = project__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = project__pb2.common_models_pb2
try:
  algorithm__version__pb2 = project__pb2.algorithm__version__pb2
except AttributeError:
  algorithm__version__pb2 = project__pb2.algorithm_version_pb2
try:
  common__models__pb2 = project__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = project__pb2.common_models_pb2
try:
  algorithm__pb2 = project__pb2.algorithm__pb2
except AttributeError:
  algorithm__pb2 = project__pb2.algorithm_pb2
try:
  common__models__pb2 = project__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = project__pb2.common_models_pb2
try:
  algorithm__config__pb2 = project__pb2.algorithm__config__pb2
except AttributeError:
  algorithm__config__pb2 = project__pb2.algorithm_config_pb2
try:
  common__models__pb2 = project__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = project__pb2.common_models_pb2
try:
  algorithm__pb2 = project__pb2.algorithm__pb2
except AttributeError:
  algorithm__pb2 = project__pb2.algorithm_pb2
try:
  common__models__pb2 = project__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = project__pb2.common_models_pb2
try:
  algorithm__version__pb2 = project__pb2.algorithm__version__pb2
except AttributeError:
  algorithm__version__pb2 = project__pb2.algorithm_version_pb2
try:
  common__models__pb2 = project__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = project__pb2.common_models_pb2
try:
  algorithm__pb2 = project__pb2.algorithm__pb2
except AttributeError:
  algorithm__pb2 = project__pb2.algorithm_pb2
try:
  common__models__pb2 = project__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = project__pb2.common_models_pb2
try:
  analysis__computation__pb2 = project__pb2.analysis__computation__pb2
except AttributeError:
  analysis__computation__pb2 = project__pb2.analysis_computation_pb2
try:
  common__models__pb2 = project__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = project__pb2.common_models_pb2
try:
  analysis__pb2 = project__pb2.analysis__pb2
except AttributeError:
  analysis__pb2 = project__pb2.analysis_pb2
try:
  common__models__pb2 = project__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = project__pb2.common_models_pb2
try:
  aoi__collection__pb2 = project__pb2.aoi__collection__pb2
except AttributeError:
  aoi__collection__pb2 = project__pb2.aoi_collection_pb2
try:
  common__models__pb2 = project__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = project__pb2.common_models_pb2
try:
  result__pb2 = project__pb2.result__pb2
except AttributeError:
  result__pb2 = project__pb2.result_pb2
try:
  common__models__pb2 = project__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = project__pb2.common_models_pb2
try:
  toi__pb2 = project__pb2.toi__pb2
except AttributeError:
  toi__pb2 = project__pb2.toi_pb2
try:
  common__models__pb2 = project__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = project__pb2.common_models_pb2
try:
  project__result__pb2 = project__pb2.project__result__pb2
except AttributeError:
  project__result__pb2 = project__pb2.project_result_pb2
try:
  common__models__pb2 = project__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = project__pb2.common_models_pb2
try:
  result__pb2 = project__pb2.result__pb2
except AttributeError:
  result__pb2 = project__pb2.result_pb2
try:
  common__models__pb2 = project__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = project__pb2.common_models_pb2
try:
  toi__pb2 = project__pb2.toi__pb2
except AttributeError:
  toi__pb2 = project__pb2.toi_pb2
try:
  common__models__pb2 = project__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = project__pb2.common_models_pb2
try:
  analysis__pb2 = project__pb2.analysis__pb2
except AttributeError:
  analysis__pb2 = project__pb2.analysis_pb2
try:
  common__models__pb2 = project__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = project__pb2.common_models_pb2
try:
  algorithm__config__pb2 = project__pb2.algorithm__config__pb2
except AttributeError:
  algorithm__config__pb2 = project__pb2.algorithm_config_pb2
try:
  common__models__pb2 = project__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = project__pb2.common_models_pb2
try:
  algorithm__pb2 = project__pb2.algorithm__pb2
except AttributeError:
  algorithm__pb2 = project__pb2.algorithm_pb2
try:
  common__models__pb2 = project__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = project__pb2.common_models_pb2
try:
  algorithm__version__pb2 = project__pb2.algorithm__version__pb2
except AttributeError:
  algorithm__version__pb2 = project__pb2.algorithm_version_pb2
try:
  common__models__pb2 = project__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = project__pb2.common_models_pb2
try:
  algorithm__pb2 = project__pb2.algorithm__pb2
except AttributeError:
  algorithm__pb2 = project__pb2.algorithm_pb2
try:
  common__models__pb2 = project__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = project__pb2.common_models_pb2
try:
  visualization__pb2 = project__pb2.visualization__pb2
except AttributeError:
  visualization__pb2 = project__pb2.visualization_pb2

from terrascope_api.models.common_models_pb2 import *
from terrascope_api.models.project_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13project_group.proto\x12\x07oi.papi\x1a\x13\x63ommon_models.proto\x1a\rproject.proto\"s\n\x0cProjectGroup\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\"\n\x08projects\x18\x03 \x03(\x0b\x32\x10.oi.papi.Project\x12\x11\n\tcollapsed\x18\x04 \x01(\x08\x12\x12\n\nsort_order\x18\x05 \x01(\r\"B\n\x17ProjectGroupListRequest\x12\'\n\npagination\x18\x01 \x01(\x0b\x32\x13.oi.papi.Pagination\"\x87\x01\n\x18ProjectGroupListResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12-\n\x0eproject_groups\x18\x02 \x03(\x0b\x32\x15.oi.papi.ProjectGroup\x12\'\n\npagination\x18\x03 \x01(\x0b\x32\x13.oi.papi.Pagination\">\n\x19ProjectGroupCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0bproject_ids\x18\x02 \x03(\t\"_\n\x1aProjectGroupCreateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12,\n\rproject_group\x18\x02 \x01(\x0b\x32\x15.oi.papi.ProjectGroup\"(\n\x19ProjectGroupDeleteRequest\x12\x0b\n\x03ids\x18\x01 \x03(\t\"1\n\x1aProjectGroupDeleteResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\"{\n\x19ProjectGroupUpdateRequest\x12-\n\x0eproject_groups\x18\x01 \x03(\x0b\x32\x15.oi.papi.ProjectGroup\x12\x17\n\x0fupdate_projects\x18\x02 \x01(\x08\x12\x16\n\x0eupdate_details\x18\x03 \x01(\x08\"1\n\x1aProjectGroupUpdateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r2\xd7\x02\n\x0fProjectGroupApi\x12K\n\x04list\x12 .oi.papi.ProjectGroupListRequest\x1a!.oi.papi.ProjectGroupListResponse\x12Q\n\x06\x63reate\x12\".oi.papi.ProjectGroupCreateRequest\x1a#.oi.papi.ProjectGroupCreateResponse\x12Q\n\x06\x64\x65lete\x12\".oi.papi.ProjectGroupDeleteRequest\x1a#.oi.papi.ProjectGroupDeleteResponse\x12Q\n\x06update\x12\".oi.papi.ProjectGroupUpdateRequest\x1a#.oi.papi.ProjectGroupUpdateResponseP\x00P\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'project_group_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_PROJECTGROUP']._serialized_start=68
  _globals['_PROJECTGROUP']._serialized_end=183
  _globals['_PROJECTGROUPLISTREQUEST']._serialized_start=185
  _globals['_PROJECTGROUPLISTREQUEST']._serialized_end=251
  _globals['_PROJECTGROUPLISTRESPONSE']._serialized_start=254
  _globals['_PROJECTGROUPLISTRESPONSE']._serialized_end=389
  _globals['_PROJECTGROUPCREATEREQUEST']._serialized_start=391
  _globals['_PROJECTGROUPCREATEREQUEST']._serialized_end=453
  _globals['_PROJECTGROUPCREATERESPONSE']._serialized_start=455
  _globals['_PROJECTGROUPCREATERESPONSE']._serialized_end=550
  _globals['_PROJECTGROUPDELETEREQUEST']._serialized_start=552
  _globals['_PROJECTGROUPDELETEREQUEST']._serialized_end=592
  _globals['_PROJECTGROUPDELETERESPONSE']._serialized_start=594
  _globals['_PROJECTGROUPDELETERESPONSE']._serialized_end=643
  _globals['_PROJECTGROUPUPDATEREQUEST']._serialized_start=645
  _globals['_PROJECTGROUPUPDATEREQUEST']._serialized_end=768
  _globals['_PROJECTGROUPUPDATERESPONSE']._serialized_start=770
  _globals['_PROJECTGROUPUPDATERESPONSE']._serialized_end=819
  _globals['_PROJECTGROUPAPI']._serialized_start=822
  _globals['_PROJECTGROUPAPI']._serialized_end=1165
# @@protoc_insertion_point(module_scope)
