# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: credit.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from terrascope_api.models import common_models_pb2 as common__models__pb2

from terrascope_api.models.common_models_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0c\x63redit.proto\x12\x0eoi.papi.credit\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x13\x63ommon_models.proto\"E\n\x10\x43reditAddRequest\x12\x11\n\tsource_id\x18\x01 \x01(\t\x12\x0e\n\x06\x61mount\x18\x02 \x01(\x01\x12\x0e\n\x06reason\x18\x03 \x01(\t\"(\n\x11\x43reditAddResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\"H\n\x13\x43reditRemoveRequest\x12\x11\n\tsource_id\x18\x01 \x01(\t\x12\x0e\n\x06\x61mount\x18\x02 \x01(\x01\x12\x0e\n\x06reason\x18\x03 \x01(\t\"+\n\x14\x43reditRemoveResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\"H\n\x13\x43reditRefundRequest\x12\x11\n\tsource_id\x18\x01 \x01(\t\x12\x0e\n\x06\x61mount\x18\x02 \x01(\x01\x12\x0e\n\x06reason\x18\x03 \x01(\t\"+\n\x14\x43reditRefundResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\"\x85\x01\n#CreditAlgorithmMultiplierSetRequest\x12\x1c\n\x14\x61lgorithm_version_id\x18\x01 \x01(\t\x12!\n\x19\x61lgorithm_execution_price\x18\x02 \x01(\x01\x12\x1d\n\x15\x61lgorithm_value_price\x18\x03 \x01(\x01\";\n$CreditAlgorithmMultiplierSetResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\"Y\n$CreditDataSourceMultiplierSetRequest\x12\x16\n\x0e\x64\x61ta_source_id\x18\x01 \x01(\t\x12\x19\n\x11\x64\x61ta_source_price\x18\x02 \x01(\x01\"<\n%CreditDataSourceMultiplierSetResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\"\xd9\x02\n\x15\x43reditEstimateRequest\x12 \n\x18\x61lgorithm_computation_id\x18\x01 \x01(\t\x12 \n\x18\x61nalysis_computation_ids\x18\x02 \x03(\t\x12S\n\x12\x61nalysis_resources\x18\x03 \x01(\x0b\x32\x37.oi.papi.credit.CreditEstimateRequest.AnalysisResources\x1a\xa6\x01\n\x11\x41nalysisResources\x12\x1a\n\x12\x61oi_collection_ids\x18\x01 \x03(\t\x12\x1b\n\x13\x61nalysis_config_ids\x18\x02 \x03(\t\x12,\n\x08start_ts\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12*\n\x06\x65nd_ts\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"S\n\x16\x43reditEstimateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x17\n\x0f\x63redit_estimate\x18\x02 \x01(\x01\x12\x0b\n\x03msg\x18\x03 \x01(\t\"N\n\x06\x43redit\x12\x11\n\tsource_id\x18\x01 \x01(\t\x12\x11\n\tavailable\x18\x02 \x01(\x01\x12\x10\n\x08reserved\x18\x03 \x01(\x01\x12\x0c\n\x04used\x18\x04 \x01(\x01\")\n\x14\x43reditSummaryRequest\x12\x11\n\tsource_id\x18\x01 \x01(\t\"T\n\x15\x43reditSummaryResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12&\n\x06\x63redit\x18\x02 \x01(\x0b\x32\x16.oi.papi.credit.Credit\"\xc2\x03\n\x0bTransaction\x12\n\n\x02id\x18\x01 \x01(\t\x12\x18\n\x10\x63redit_source_id\x18\x02 \x01(\t\x12\x0f\n\x07user_id\x18\x03 \x01(\t\x12\x45\n\x10transaction_type\x18\x04 \x01(\x0e\x32+.oi.papi.credit.Transaction.TransactionType\x12\x0e\n\x06\x61mount\x18\x05 \x01(\x01\x12\x0e\n\x06reason\x18\x06 \x01(\t\x12\x31\n\rtransacted_on\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x18\n\x10\x63redit_available\x18\x08 \x01(\x01\x12\x17\n\x0f\x63redit_reserved\x18\t \x01(\x01\x12\x13\n\x0b\x63redit_used\x18\n \x01(\x01\x12 \n\x18\x61lgorithm_computation_id\x18\x0b \x01(\t\"x\n\x0fTransactionType\x12\x1c\n\x18UNKNOWN_TRANSACTION_TYPE\x10\x00\x12\x07\n\x03\x41\x44\x44\x10\x01\x12\n\n\x06REMOVE\x10\x02\x12\n\n\x06REFUND\x10\x03\x12\x0b\n\x07RESERVE\x10\x04\x12\r\n\tUNRESERVE\x10\x05\x12\n\n\x06\x44\x45\x44UCT\x10\x06\"\xae\x02\n\x19\x43reditTransactionsRequest\x12\'\n\npagination\x18\x01 \x01(\x0b\x32\x13.oi.papi.Pagination\x12\x11\n\tsource_id\x18\x02 \x01(\t\x12\x45\n\x10transaction_type\x18\x03 \x01(\x0e\x32+.oi.papi.credit.Transaction.TransactionType\x12\x35\n\x11min_transacted_on\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x35\n\x11max_transacted_on\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12 \n\x18\x61lgorithm_computation_id\x18\x06 \x01(\t\"\x8d\x01\n\x1a\x43reditTransactionsResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\'\n\npagination\x18\x02 \x01(\x0b\x32\x13.oi.papi.Pagination\x12\x31\n\x0ctransactions\x18\x03 \x03(\x0b\x32\x1b.oi.papi.credit.Transaction2\x97\x06\n\tCreditApi\x12J\n\x03\x61\x64\x64\x12 .oi.papi.credit.CreditAddRequest\x1a!.oi.papi.credit.CreditAddResponse\x12S\n\x06remove\x12#.oi.papi.credit.CreditRemoveRequest\x1a$.oi.papi.credit.CreditRemoveResponse\x12S\n\x06refund\x12#.oi.papi.credit.CreditRefundRequest\x1a$.oi.papi.credit.CreditRefundResponse\x12z\n\rset_algorithm\x12\x33.oi.papi.credit.CreditAlgorithmMultiplierSetRequest\x1a\x34.oi.papi.credit.CreditAlgorithmMultiplierSetResponse\x12~\n\x0fset_data_source\x12\x34.oi.papi.credit.CreditDataSourceMultiplierSetRequest\x1a\x35.oi.papi.credit.CreditDataSourceMultiplierSetResponse\x12Y\n\x08\x65stimate\x12%.oi.papi.credit.CreditEstimateRequest\x1a&.oi.papi.credit.CreditEstimateResponse\x12V\n\x07summary\x12$.oi.papi.credit.CreditSummaryRequest\x1a%.oi.papi.credit.CreditSummaryResponse\x12\x65\n\x0ctransactions\x12).oi.papi.credit.CreditTransactionsRequest\x1a*.oi.papi.credit.CreditTransactionsResponseP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'credit_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_CREDITADDREQUEST']._serialized_start=86
  _globals['_CREDITADDREQUEST']._serialized_end=155
  _globals['_CREDITADDRESPONSE']._serialized_start=157
  _globals['_CREDITADDRESPONSE']._serialized_end=197
  _globals['_CREDITREMOVEREQUEST']._serialized_start=199
  _globals['_CREDITREMOVEREQUEST']._serialized_end=271
  _globals['_CREDITREMOVERESPONSE']._serialized_start=273
  _globals['_CREDITREMOVERESPONSE']._serialized_end=316
  _globals['_CREDITREFUNDREQUEST']._serialized_start=318
  _globals['_CREDITREFUNDREQUEST']._serialized_end=390
  _globals['_CREDITREFUNDRESPONSE']._serialized_start=392
  _globals['_CREDITREFUNDRESPONSE']._serialized_end=435
  _globals['_CREDITALGORITHMMULTIPLIERSETREQUEST']._serialized_start=438
  _globals['_CREDITALGORITHMMULTIPLIERSETREQUEST']._serialized_end=571
  _globals['_CREDITALGORITHMMULTIPLIERSETRESPONSE']._serialized_start=573
  _globals['_CREDITALGORITHMMULTIPLIERSETRESPONSE']._serialized_end=632
  _globals['_CREDITDATASOURCEMULTIPLIERSETREQUEST']._serialized_start=634
  _globals['_CREDITDATASOURCEMULTIPLIERSETREQUEST']._serialized_end=723
  _globals['_CREDITDATASOURCEMULTIPLIERSETRESPONSE']._serialized_start=725
  _globals['_CREDITDATASOURCEMULTIPLIERSETRESPONSE']._serialized_end=785
  _globals['_CREDITESTIMATEREQUEST']._serialized_start=788
  _globals['_CREDITESTIMATEREQUEST']._serialized_end=1133
  _globals['_CREDITESTIMATEREQUEST_ANALYSISRESOURCES']._serialized_start=967
  _globals['_CREDITESTIMATEREQUEST_ANALYSISRESOURCES']._serialized_end=1133
  _globals['_CREDITESTIMATERESPONSE']._serialized_start=1135
  _globals['_CREDITESTIMATERESPONSE']._serialized_end=1218
  _globals['_CREDIT']._serialized_start=1220
  _globals['_CREDIT']._serialized_end=1298
  _globals['_CREDITSUMMARYREQUEST']._serialized_start=1300
  _globals['_CREDITSUMMARYREQUEST']._serialized_end=1341
  _globals['_CREDITSUMMARYRESPONSE']._serialized_start=1343
  _globals['_CREDITSUMMARYRESPONSE']._serialized_end=1427
  _globals['_TRANSACTION']._serialized_start=1430
  _globals['_TRANSACTION']._serialized_end=1880
  _globals['_TRANSACTION_TRANSACTIONTYPE']._serialized_start=1760
  _globals['_TRANSACTION_TRANSACTIONTYPE']._serialized_end=1880
  _globals['_CREDITTRANSACTIONSREQUEST']._serialized_start=1883
  _globals['_CREDITTRANSACTIONSREQUEST']._serialized_end=2185
  _globals['_CREDITTRANSACTIONSRESPONSE']._serialized_start=2188
  _globals['_CREDITTRANSACTIONSRESPONSE']._serialized_end=2329
  _globals['_CREDITAPI']._serialized_start=2332
  _globals['_CREDITAPI']._serialized_end=3123
# @@protoc_insertion_point(module_scope)
