# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: result.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from terrascope_api.models import common_models_pb2 as common__models__pb2
from terrascope_api.models import toi_pb2 as toi__pb2
try:
  common__models__pb2 = toi__pb2.common__models__pb2
except AttributeError:
  common__models__pb2 = toi__pb2.common_models_pb2

from terrascope_api.models.common_models_pb2 import *
from terrascope_api.models.toi_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0cresult.proto\x12\x07oi.papi\x1a\x1cgoogle/api/annotations.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x13\x63ommon_models.proto\x1a\ttoi.proto\"2\n\nExportFile\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\x17\n\x0f\x66ile_size_bytes\x18\x02 \x01(\x04\"\\\n\x11\x45xportCredentials\x12,\n\x0b\x63redentials\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x19\n\x11\x62\x61se_url_template\x18\x02 \x01(\t\"\x9d\x06\n\x06Result\x12\n\n\x02id\x18\x01 \x01(\t\x12.\n\ncreated_on\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1a\n\x12source_aoi_version\x18\x03 \x01(\r\x12\x18\n\x10\x64\x65st_aoi_version\x18\x04 \x01(\r\x12\x19\n\x11\x61lgo_config_class\x18\x05 \x01(\t\x12\x1c\n\x14\x61lgo_config_subclass\x18\x06 \x01(\t\x12\x31\n\x0cobservations\x18\x07 \x03(\x0b\x32\x1b.oi.papi.Result.Observation\x12\x11\n\tdata_type\x18\x08 \x01(\t\x12 \n\x18\x61lgorithm_computation_id\x18\t \x01(\t\x1a\xff\x03\n\x0bObservation\x12\n\n\x02id\x18\x01 \x01(\t\x12\x14\n\x0c\x64\x61ta_view_id\x18\x02 \x01(\t\x12.\n\ncreated_on\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08start_ts\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12*\n\x06\x65nd_ts\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12&\n\x05value\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x32\n\x06status\x18\x06 \x01(\x0e\x32\".oi.papi.Result.Observation.Status\x12=\n\x0cmeasurements\x18\x07 \x03(\x0b\x32\'.oi.papi.Result.Observation.Measurement\x12(\n\x0b\x65xport_file\x18\x08 \x01(\x0b\x32\x13.oi.papi.ExportFile\x1a\x46\n\x0bMeasurement\x12\n\n\x02id\x18\x01 \x01(\t\x12+\n\ndimensions\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\"7\n\x06Status\x12\x12\n\x0eUNKNOWN_STATUS\x10\x00\x12\x0c\n\x08\x43OMPLETE\x10\x01\x12\x0b\n\x07PARTIAL\x10\x02\"\xd4\x04\n\x10ResultGetRequest\x12\x1a\n\x12source_aoi_version\x18\x02 \x01(\r\x12\x18\n\x10\x64\x65st_aoi_version\x18\x03 \x01(\r\x12\x19\n\x11\x61lgo_config_class\x18\x04 \x01(\t\x12\x1c\n\x14\x61lgo_config_subclass\x18\x05 \x01(\t\x12.\n\ncreated_on\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x38\n\x14observation_start_ts\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12<\n\x18max_observation_start_ts\x18\x10 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12>\n\x12observation_status\x18\t \x01(\x0e\x32\".oi.papi.Result.Observation.Status\x12\x11\n\tdata_type\x18\x0b \x01(\t\x12\'\n\npagination\x18\x0c \x01(\x0b\x32\x13.oi.papi.Pagination\x12!\n\x19\x61lgorithm_computation_ids\x18\r \x03(\t\x12 \n\x18\x61nalysis_computation_ids\x18\x0e \x03(\t\x12\x1c\n\x14include_export_files\x18\x0f \x01(\x08J\x04\x08\x01\x10\x02J\x04\x08\x08\x10\tJ\x04\x08\n\x10\x0bR\x18\x61lgorithm_computation_idR\x08geom_wktR\x14include_measurements\"\xab\x01\n\x11ResultGetResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\'\n\npagination\x18\x02 \x01(\x0b\x32\x13.oi.papi.Pagination\x12 \n\x07results\x18\x03 \x03(\x0b\x32\x0f.oi.papi.Result\x12\x36\n\x12\x65xport_credentials\x18\x04 \x01(\x0b\x32\x1a.oi.papi.ExportCredentials\"\x8c\x01\n\x19ResultFilterCreateRequest\x12\x11\n\tdata_type\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\x33\n\x12\x65xpression_context\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\"K\n\x1aResultFilterCreateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x18\n\x10result_filter_id\x18\x02 \x01(\t\"T\n ResultFilterMappingCreateRequest\x12\x16\n\x0e\x63omputation_id\x18\x01 \x01(\t\x12\x18\n\x10result_filter_id\x18\x02 \x01(\t\"8\n!ResultFilterMappingCreateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\"V\n\x17ResultFilterListRequest\x12\'\n\npagination\x18\x01 \x01(\x0b\x32\x13.oi.papi.Pagination\x12\x12\n\ndata_types\x18\x02 \x03(\t\"\x99\x01\n\x0cResultFilter\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x12\n\nexpression\x18\x04 \x01(\t\x12\x33\n\x12\x65xpression_context\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdata_type\x18\x06 \x01(\t\"\x87\x01\n\x18ResultFilterListResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12-\n\x0eresult_filters\x18\x02 \x03(\x0b\x32\x15.oi.papi.ResultFilter\x12\'\n\npagination\x18\x03 \x01(\x0b\x32\x13.oi.papi.Pagination2\x95\x03\n\tResultApi\x12T\n\x03get\x12\x19.oi.papi.ResultGetRequest\x1a\x1a.oi.papi.ResultGetResponse\"\x16\x82\xd3\xe4\x93\x02\x10\"\x0b/result/get:\x01*\x12_\n\x14\x63reate_result_filter\x12\".oi.papi.ResultFilterCreateRequest\x1a#.oi.papi.ResultFilterCreateResponse\x12u\n\x1c\x63reate_result_filter_mapping\x12).oi.papi.ResultFilterMappingCreateRequest\x1a*.oi.papi.ResultFilterMappingCreateResponse\x12Z\n\x13list_result_filters\x12 .oi.papi.ResultFilterListRequest\x1a!.oi.papi.ResultFilterListResponseP\x03P\x04\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'result_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_RESULTAPI'].methods_by_name['get']._loaded_options = None
  _globals['_RESULTAPI'].methods_by_name['get']._serialized_options = b'\202\323\344\223\002\020\"\013/result/get:\001*'
  _globals['_EXPORTFILE']._serialized_start=150
  _globals['_EXPORTFILE']._serialized_end=200
  _globals['_EXPORTCREDENTIALS']._serialized_start=202
  _globals['_EXPORTCREDENTIALS']._serialized_end=294
  _globals['_RESULT']._serialized_start=297
  _globals['_RESULT']._serialized_end=1094
  _globals['_RESULT_OBSERVATION']._serialized_start=583
  _globals['_RESULT_OBSERVATION']._serialized_end=1094
  _globals['_RESULT_OBSERVATION_MEASUREMENT']._serialized_start=967
  _globals['_RESULT_OBSERVATION_MEASUREMENT']._serialized_end=1037
  _globals['_RESULT_OBSERVATION_STATUS']._serialized_start=1039
  _globals['_RESULT_OBSERVATION_STATUS']._serialized_end=1094
  _globals['_RESULTGETREQUEST']._serialized_start=1097
  _globals['_RESULTGETREQUEST']._serialized_end=1693
  _globals['_RESULTGETRESPONSE']._serialized_start=1696
  _globals['_RESULTGETRESPONSE']._serialized_end=1867
  _globals['_RESULTFILTERCREATEREQUEST']._serialized_start=1870
  _globals['_RESULTFILTERCREATEREQUEST']._serialized_end=2010
  _globals['_RESULTFILTERCREATERESPONSE']._serialized_start=2012
  _globals['_RESULTFILTERCREATERESPONSE']._serialized_end=2087
  _globals['_RESULTFILTERMAPPINGCREATEREQUEST']._serialized_start=2089
  _globals['_RESULTFILTERMAPPINGCREATEREQUEST']._serialized_end=2173
  _globals['_RESULTFILTERMAPPINGCREATERESPONSE']._serialized_start=2175
  _globals['_RESULTFILTERMAPPINGCREATERESPONSE']._serialized_end=2231
  _globals['_RESULTFILTERLISTREQUEST']._serialized_start=2233
  _globals['_RESULTFILTERLISTREQUEST']._serialized_end=2319
  _globals['_RESULTFILTER']._serialized_start=2322
  _globals['_RESULTFILTER']._serialized_end=2475
  _globals['_RESULTFILTERLISTRESPONSE']._serialized_start=2478
  _globals['_RESULTFILTERLISTRESPONSE']._serialized_end=2613
  _globals['_RESULTAPI']._serialized_start=2616
  _globals['_RESULTAPI']._serialized_end=3021
# @@protoc_insertion_point(module_scope)
