# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aoi_export.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10\x61oi_export.proto\x12\x07oi.papi\"\x9a\x01\n\x10\x41OIExportRequest\x12\x0f\n\x07\x61oi_ids\x18\x01 \x03(\t\x12-\n\tfile_type\x18\x02 \x01(\x0e\x32\x1a.oi.papi.AOIExportFileType\x12\x33\n\x0c\x61rchive_type\x18\x03 \x01(\x0e\x32\x1d.oi.papi.AOIExportArchiveType\x12\x11\n\tfile_name\x18\x04 \x01(\t\"\xae\x01\n\x1a\x41OICollectionExportRequest\x12\x19\n\x11\x61oi_collection_id\x18\x01 \x01(\t\x12-\n\tfile_type\x18\x02 \x01(\x0e\x32\x1a.oi.papi.AOIExportFileType\x12\x33\n\x0c\x61rchive_type\x18\x03 \x01(\x0e\x32\x1d.oi.papi.AOIExportArchiveType\x12\x11\n\tfile_name\x18\x04 \x01(\t\"%\n\x11\x41OIExportResponse\x12\x10\n\x08location\x18\x01 \x01(\t\"/\n\x1b\x41OICollectionExportResponse\x12\x10\n\x08location\x18\x01 \x01(\t*a\n\x11\x41OIExportFileType\x12\x1b\n\x17UNKNOWN_EXPORT_FILETYPE\x10\x00\x12\x0b\n\x07GEOJSON\x10\x01\x12\x12\n\x0e\x45SRI_SHAPEFILE\x10\x02\x12\x0e\n\nGEOPACKAGE\x10\x03*>\n\x14\x41OIExportArchiveType\x12\x18\n\x14UNKNOWN_ARCHIVE_TYPE\x10\x00\x12\x0c\n\x08ZIP_FILE\x10\x01\x32\xb4\x01\n\x0c\x41OIExportApi\x12\x44\n\x0b\x65xport_aois\x12\x19.oi.papi.AOIExportRequest\x1a\x1a.oi.papi.AOIExportResponse\x12^\n\x11\x65xport_collection\x12#.oi.papi.AOICollectionExportRequest\x1a$.oi.papi.AOICollectionExportResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aoi_export_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_AOIEXPORTFILETYPE']._serialized_start=451
  _globals['_AOIEXPORTFILETYPE']._serialized_end=548
  _globals['_AOIEXPORTARCHIVETYPE']._serialized_start=550
  _globals['_AOIEXPORTARCHIVETYPE']._serialized_end=612
  _globals['_AOIEXPORTREQUEST']._serialized_start=30
  _globals['_AOIEXPORTREQUEST']._serialized_end=184
  _globals['_AOICOLLECTIONEXPORTREQUEST']._serialized_start=187
  _globals['_AOICOLLECTIONEXPORTREQUEST']._serialized_end=361
  _globals['_AOIEXPORTRESPONSE']._serialized_start=363
  _globals['_AOIEXPORTRESPONSE']._serialized_end=400
  _globals['_AOICOLLECTIONEXPORTRESPONSE']._serialized_start=402
  _globals['_AOICOLLECTIONEXPORTRESPONSE']._serialized_end=449
  _globals['_AOIEXPORTAPI']._serialized_start=615
  _globals['_AOIEXPORTAPI']._serialized_end=795
# @@protoc_insertion_point(module_scope)
