# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: algorithm.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from terrascope_api.models import common_models_pb2 as common__models__pb2

from terrascope_api.models.common_models_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0f\x61lgorithm.proto\x12\x07oi.papi\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x13\x63ommon_models.proto\"{\n\tAlgorithm\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x03 \x01(\t\x12\x0e\n\x06\x61uthor\x18\x04 \x01(\t\x12.\n\ncreated_on\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"L\n\x16\x41lgorithmCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\x12\x0e\n\x06\x61uthor\x18\x03 \x01(\t\"U\n\x17\x41lgorithmCreateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12%\n\talgorithm\x18\x02 \x01(\x0b\x32\x12.oi.papi.Algorithm\"K\n\x13\x41lgorithmGetRequest\x12\x0b\n\x03ids\x18\x01 \x03(\t\x12\'\n\npagination\x18\x02 \x01(\x0b\x32\x13.oi.papi.Pagination\"|\n\x14\x41lgorithmGetResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12&\n\nalgorithms\x18\x02 \x03(\x0b\x32\x12.oi.papi.Algorithm\x12\'\n\npagination\x18\x03 \x01(\x0b\x32\x13.oi.papi.Pagination\"\xbc\x01\n\x14\x41lgorithmListRequest\x12\x13\n\x0bsearch_text\x18\x01 \x01(\t\x12\x32\n\x0emin_created_on\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x32\n\x0emax_created_on\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\'\n\npagination\x18\x04 \x01(\x0b\x32\x13.oi.papi.Pagination\"}\n\x15\x41lgorithmListResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12&\n\nalgorithms\x18\x02 \x03(\x0b\x32\x12.oi.papi.Algorithm\x12\'\n\npagination\x18\x03 \x01(\x0b\x32\x13.oi.papi.Pagination\"@\n\x16\x41lgorithmUpdateRequest\x12&\n\nalgorithms\x18\x01 \x03(\x0b\x32\x12.oi.papi.Algorithm\".\n\x17\x41lgorithmUpdateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r2\xb3\x02\n\x0c\x41lgorithmApi\x12K\n\x06\x63reate\x12\x1f.oi.papi.AlgorithmCreateRequest\x1a .oi.papi.AlgorithmCreateResponse\x12K\n\x06update\x12\x1f.oi.papi.AlgorithmUpdateRequest\x1a .oi.papi.AlgorithmUpdateResponse\x12\x42\n\x03get\x12\x1c.oi.papi.AlgorithmGetRequest\x1a\x1d.oi.papi.AlgorithmGetResponse\x12\x45\n\x04list\x12\x1d.oi.papi.AlgorithmListRequest\x1a\x1e.oi.papi.AlgorithmListResponseP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'algorithm_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_ALGORITHM']._serialized_start=82
  _globals['_ALGORITHM']._serialized_end=205
  _globals['_ALGORITHMCREATEREQUEST']._serialized_start=207
  _globals['_ALGORITHMCREATEREQUEST']._serialized_end=283
  _globals['_ALGORITHMCREATERESPONSE']._serialized_start=285
  _globals['_ALGORITHMCREATERESPONSE']._serialized_end=370
  _globals['_ALGORITHMGETREQUEST']._serialized_start=372
  _globals['_ALGORITHMGETREQUEST']._serialized_end=447
  _globals['_ALGORITHMGETRESPONSE']._serialized_start=449
  _globals['_ALGORITHMGETRESPONSE']._serialized_end=573
  _globals['_ALGORITHMLISTREQUEST']._serialized_start=576
  _globals['_ALGORITHMLISTREQUEST']._serialized_end=764
  _globals['_ALGORITHMLISTRESPONSE']._serialized_start=766
  _globals['_ALGORITHMLISTRESPONSE']._serialized_end=891
  _globals['_ALGORITHMUPDATEREQUEST']._serialized_start=893
  _globals['_ALGORITHMUPDATEREQUEST']._serialized_end=957
  _globals['_ALGORITHMUPDATERESPONSE']._serialized_start=959
  _globals['_ALGORITHMUPDATERESPONSE']._serialized_end=1005
  _globals['_ALGORITHMAPI']._serialized_start=1008
  _globals['_ALGORITHMAPI']._serialized_end=1315
# @@protoc_insertion_point(module_scope)
